@@ -20,4 +20,4 @@ class ManufacturerSerializer(NetBoxModelSerializer):
             'id', 'url', 'display_url', 'display', 'name', 'slug', 'description', 'tags', 'custom_fields',
             'created', 'last_updated', 'devicetype_count', 'inventoryitem_count', 'platform_count',
         ]
-        brief_fields = ('id', 'url', 'display', 'name', 'slug', 'description', 'devicetype_count')
+        brief_fields = ('id', 'url', 'display', 'name', 'slug', 'description')
